/*
 *  
 *  Copyright (c) 2004 Steve Slaven, All Rights Reserved.
 *  
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License as
 *  published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA 02111-1307 USA
 *  
*/
package net.hoopajoo.cheeselab3;

import java.sql.*;

class PathFinder {
    private String error = "No error";
    private Connection db = null;
    private long stat_room_lookups = 0;

    public void set_db( Connection newdb ) {
        db = newdb;
    }

    // This is a quickwalk string to get to the toid from fromid
    public String find_path( int fromid, int toid ) {
        CheeseRoomData from = null, to = null;

        // Verify these are valid rooms
        from = get_room( fromid );
        if( from == null ) {
            set_error( "From room is not valid" );
            return( null );
        }

        to = get_room( toid );
        if( to == null ) {
            set_error( "To room is not valid" );
            return( null );
        }

        // If we get here, then just pass them on
        String ret = perform_find_path( from, to );
        if( ret != null && ret.equals( "" ) )
            ret = null;
        return( ret );
    }

    protected void set_error( String newerror ) {
        error = newerror;
    }

    public String get_error() {
        return( error );
    }

    // This is the actual function you should override
    protected String perform_find_path( CheeseRoomData from, CheeseRoomData to ) {
        set_error( "Base class does not provide a path finder" );
        return( null );
    }

    // This is a convenience function for the path finders
    protected CheeseRoomData get_room( int roomid ) {
        stat_room_lookups++;
        return( CheeseDecoder.get_room( roomid, db ) );
    }

    public void print_stats() {
        System.out.println( "Room lookups: " + stat_room_lookups );
    }

    // Override this in subclasses to set flags (avoid water, no mountains, etc)
    // the caller should be sure these are lowercase!
    public void set_option( String key, String value ) {}

    // Convenience for parsing options
    protected boolean value_to_boolean( String value ) {
        if( value.equals( "yes" )
                || value.equals( "1" )
                || value.equals( "true" ) )
            return( true );

        return( false );
    }

    protected int value_to_int( String value ) {
        int ret = 0;
        try {
            ret = Integer.parseInt( value );
        } catch( Exception e ) {}
        return( ret );
    }
}
